@@ -16,10 +16,15 @@ The only onterface function is iter_avro, example usage::
 '''
 
 __all__ = [ 'iter_avro' ]
-__version__ = '0.5.0'
+__version__ = '0.6.0'
+
+from sys import version_info
 
 try:
-    from . import cfastavro as _avro
+    if version_info[0] == 3:
+        from . import cfastavro3 as _avro
+    else:
+        from . import cfastavro2 as _avro
 except ImportError:
     from . import pyfastavro as _avro
 
